Top

    Shared Nightmare
    Utrecht, Netherlands
    July 2nd 2005
    3R+F
    16 players
    Jeroen van Oort

    Name: Deeper Underground
    Description:
    "Look in the sky, it's a raven. No, it's a bat.
    No, it's a crow, No it's a swarm of them all!!!"

    Crypt (12 cards, min=10, max=21, avg=3.75)
    ------------------------------------------
    1x Christanius Lionel, The Mad Chronicler 6   ANI OBF pot		Nosferatu antitribu:2
    1x Calebros, The Martyr			  5   ANI obf pot	prince	Nosferatu:2
    1x Gemini				  5   OBF ani obt pot		Nosferatu:3
    1x Nigel the Shunned			  5   ANI POT obf		Nosferatu antitribu:2
    1x Bobby Lemon				  4   ANI pro			Gangrel:3
    1x Roger Farnsworth			  4   OBF aus			Malkavian antitribu:3
    1x Clarissa Steinburgen			  3   ani obf			Nosferatu:3
    1x Panagos Levidis			  3   ani obf			Gangrel:2
    1x Shannon Price, the Whisperer		  3   ani obf			Nosferatu antitribu:2
    1x Watenda				  3   obf			Malkavian:2
    1x Mouse				  2   ani			Nosferatu:3
    1x Zip					  2   ani			Ravnos:3

    Library 90

    Master 14
    6 Blood Doll
    2 Direct Intervention
    2 Heidelberg Castle
    Animalism x2
    1 Slum Hunting Ground
    1 Dreams of the Sphinx

    Obfuscate 17
    3 Faceless Night
    6 Cloak the Gathering
    2 Lost in Crowds
    2 Glotho's Gift
    4 Behind you

    Animalism: 37
    5 Cats' Guidance
    3 Guard Dogs
    7 Raven Spy
    7 Aid From Bats
    8 Carrion Crows
    3 Pack Alpha
    3 Canine Horde
    1 Army of Rats

    Non-skilled: 22
    7 Forced Awakening
    5 Computer Hacking
    2 Delaying Tactics
    1 J. S. Simmons, Esquire
    1 Tasha Morgan
    3 Dodge
    3 Laptop Computer